==> uniquebible-0.1.86.tar.gz: uniquebible-0.1.86/README.md <==
# Migration to PIP Package

We've recently published pip packages for distributing UniqueBible App.

Read latest instructions for installation at: https://github.com/eliranwong/UniqueBible/wiki/installation#latest-updates

# UniqueBible

A cross-platform & offline bible application, integrated with high-quality resources and unique features.

This single project has two major interfaces:

Qt-based Multi-Window Desktop Application:

<b>Tested in:</b> <a href="https://github.com/eliranwong/UniqueBible/wiki/Install-on-Windows">Windows 10</a>, <a href="https://github.com/eliranwong/wsl2/blob/master/bible_apps/desktop.md">Windows WSL2</a>, <a href="https://github.com/eliranwong/UniqueBible/wiki/Install-on-macOS">macOS [Sierra+]</a> and <a href="https://github.com/eliranwong/UniqueBible/wiki/Install-on-Linux">Linux</a> (Arch, Debian, Ubuntu & Mint), <a href="https://github.com/eliranwong/UniqueBible/wiki/Install-on-Chrome-OS">Chrome OS</a> (Debian 10), <a href="https://github.com/eliranwong/UniqueBible/wiki/Webtop-Version---RECOMMENDED!">Webtops</a>, <a href="https://github.com/eliranwong/UniqueBible/wiki/Android-iOS-Version">Android / iOS</a>

Unique Bible App can <a href="https://github.com/eliranwong/UniqueBible/wiki/UBA-Run-Modes">runs in different modes</a>, both online and offline, for examples:

> <a href="https://github.com/eliranwong/UniqueBible/wiki/Command-Line-Interface">GUI mode</a> - we use popular Qt library to run UBA on Windows, macOS, Linux, ChromeOS

> <a href="https://github.com/eliranwong/UniqueBible/wiki/Web-Version-%5Bavailable-OFFLINE%5D">Http-server</a> - e.g. <a href="https://bible.gospelchurch.uk">https://bible.gospelchurch.uk</a>

> <a href="https://github.com/eliranwong/UniqueBible/wiki/Terminal-Mode">Terminal mode</a> - the quickest way to run UBA; the most comprehensive in terms of feature coverage; all platforms supported; local or via ssh

> <a href="https://github.com/eliranwong/UniqueBible/wiki/UBA-Run-Modes">other modes ...</a>

# Development Team

Eliran Wong (https://github.com/eliranwong)

Oliver Tseng (https://github.com/otseng)

<a href="https://github.com/eliranwong/UniqueBible/wiki/Translators">Program Interface Translators</a>

# Screenshot:

<img width="1440" alt="Screenshot 2022-02-18 at 19 09 09" src="https://user-images.githubusercontent.com/25262722/154747249-adf94293-eaab-43aa-9461-04d4d688b3d1.png">

# Quick Start

('git' and 'python 3.7+' are required)

To download and set up Unique Bible app, run:

> git clone https://github.com/eliranwong/UniqueBible.git

> cd UniqueBible

> python3 uba.py

# Setup or Installation

Read our recommendations first at: https://github.com/eliranwong/UniqueBible/wiki/Recommendations-for-Different-Platforms

You can simply download & run UBA if you have python in place, read our examples at:

https://github.com/eliranwong/UniqueBible/wiki/Installation

# Features, instructions and how-tos

[Wiki](https://github.com/eliranwong/UniqueBible/wiki)

# Help, discussion and support

[Discussions](https://github.com/eliranwong/UniqueBible/discussions)

# Feature requests, issues and bug reporting

[Issues](https://github.com/eliranwong/UniqueBible/issues)

# Donations:

Please consider a donation via our PayPal account:
<a href="https://www.paypal.me/MarvelBible">https://www.paypal.me/MarvelBible</a>

==> uniquebible-0.2.8.tar.gz: uniquebible-0.2.8/README.md <==
# Migration to PIP Package

We've recently published pip packages for distributing UniqueBible App.

Read latest instructions for installation at: https://github.com/eliranwong/UniqueBible/wiki/installation#latest-updates

# UniqueBible

A cross-platform & offline bible application, integrated with high-quality resources and unique features.

This single project has two major interfaces:

Qt-based Multi-Window Desktop Application:

<b>Platforms:</b> <a href="https://github.com/eliranwong/UniqueBible/wiki/Install-on-Windows">Windows 10</a>, <a href="https://github.com/eliranwong/wsl2/blob/master/bible_apps/desktop.md">Windows WSL2</a>, <a href="https://github.com/eliranwong/UniqueBible/wiki/Install-on-macOS">macOS [Sierra+]</a> and <a href="https://github.com/eliranwong/UniqueBible/wiki/Install-on-Linux">Linux</a> (Arch, Debian, Ubuntu & Mint), <a href="https://github.com/eliranwong/UniqueBible/wiki/Install-on-Chrome-OS">Chrome OS</a> (Debian 10), <a href="https://github.com/eliranwong/UniqueBible/wiki/Android-iOS-Version">Android / iOS</a>

Unique Bible App can <a href="https://github.com/eliranwong/UniqueBible/wiki/UBA-Run-Modes">runs in different modes</a>, both online and offline, for examples:

> <a href="https://github.com/eliranwong/UniqueBible/wiki/Command-Line-Interface">GUI mode</a> - we use popular Qt library to run UBA on Windows, macOS, Linux, ChromeOS

> <a href="https://github.com/eliranwong/UniqueBible/wiki/Web-Version-%5Bavailable-OFFLINE%5D">Http-server</a> - e.g. <a href="https://bible.gospelchurch.uk">https://bible.gospelchurch.uk</a>

> <a href="https://github.com/eliranwong/UniqueBible/wiki/Terminal-Mode">Terminal mode</a> - the quickest way to run UBA; the most comprehensive in terms of feature coverage; all platforms supported; local or via ssh

> <a href="https://github.com/eliranwong/UniqueBible/wiki/UBA-Run-Modes">other modes ...</a>

# AI Features

AI Features have been integrated into UniqueBible App. Five backends are supported:
1. OpenAI / ChatGPT
2. Google AI / Gemini
3. X AI / Grok
4. Grok Cloud API
5. Mistral AI API.

# Development Team

Eliran Wong (https://github.com/eliranwong)

Oliver Tseng (https://github.com/otseng)

<a href="https://github.com/eliranwong/UniqueBible/wiki/Translators">Program Interface Translators</a>

# Screenshot:

<img width="1440" alt="Screenshot 2022-02-18 at 19 09 09" src="https://user-images.githubusercontent.com/25262722/154747249-adf94293-eaab-43aa-9461-04d4d688b3d1.png">

# Quick Start

Python 3.8+ required!

To install:

> pip install uniquebible

To run GUI mode:

> uniquebible

More about installation at https://github.com/eliranwong/UniqueBible/wiki/Installation

More about running modes at https://github.com/eliranwong/UniqueBible/wiki/UBA-Run-Modes

# Features, instructions and how-tos

[Wiki](https://github.com/eliranwong/UniqueBible/wiki)

# Help, discussion and support

[Discussions](https://github.com/eliranwong/UniqueBible/discussions)

# Feature requests, issues and bug reporting

[Issues](https://github.com/eliranwong/UniqueBible/issues)

# Donations:

Please consider a donation via our PayPal account:
<a href="https://www.paypal.me/MarvelBible">https://www.paypal.me/MarvelBible</a>
